Module lora_phy::mod_params

source ·
Parameters used across the lora-phy crate to support various use cases

Structs

Enums

  • Channel width.
  • LoRa boards supported by this crate. In addition, custom boards (possibly proprietary) can be supported by using the custom board and chip types and external implementations of the RadioKind and (in some cases) InterfaceVariant traits. For instance: let iv = ExternalInterfaceVariantImpl::new(..params…) LoRa::new(ExternalRadioKindImpl::new(BoardType::CustomBoard, spi, iv), …other_params…)
  • LoRa chips supported by this crate
  • Controls the forward error correction. Higher values are more robust, but reduces the ratio of actual data in transmissions.
  • Errors types reported during LoRa physical layer processing
  • The state of the radio
  • Controls the chirp rate. Lower values are slower bandwidth, but more robust.