pub enum RxMode {
Single(u16),
Continuous,
DutyCycle(DutyCycleParams),
}Expand description
Listening mode for LoRaWAN packet detection/reception
Variants
Single(u16)
Single shot Rx Mode to listen until packet preamble is detected or RxTimeout occurs.
The device will stay in RX Mode until a packet is received.
Preamble length as symbols is configured via following registers:
sx126x: uses SetLoRaSymbNumTimeout(0 < n < 255) + SetStopRxTimerOnPreamble(1)
sx127x: uses RegSymbTimeout (4 < n < 1023)
Continuous
Continuous Rx mode to listen for incoming packets continuously
DutyCycle(DutyCycleParams)
Receive in Duty Cycle mode (NB! Not supported on sx127x)