Module lora_phy::mod_traits

source ·
Traits implemented externally or internally to support control of LoRa chips

Traits

  • If the LoRa chip supports it, provides an async implementation of the onboard RNG. This trait makes no guarantees with regards to the distribution of the generated random numbers (ie, uniform or Gaussian). If uniformity is needed, apply necessary software processing.
  • Functions implemented for an embedded framework for an MCU/LoRa chip combination to allow this crate to control the LoRa chip.
  • Functions implemented for a specific kind of LoRa chip, called internally by the outward facing LoRa physical layer API