pub enum IrqState {
PreambleReceived,
Done,
}Expand description
Specifies an IRQ processing state to run the loop to
Variants
PreambleReceived
Runs the loop until after the preamble has been received
Done
Runs the loop until the operation is fully complete