Module lora_phy::mod_params
source · Expand description
Parameters used across the lora-phy crate to support various use cases
Structs
- Receive duty cycle parameters
- Modulation parameters for a send and/or receive communication channel
- Packet parameters for a send or receive communication channel
- Status for a received packet
Enums
- Valid bandwidths for one or more LoRa chips supported by this crate
- LoRa boards supported by this crate. In addition, custom boards (possibly proprietary) can be supported by using the custom board and chip types and external implementations of the RadioKind and (in some cases) InterfaceVariant traits. For instance: let iv = ExternalInterfaceVariantImpl::new(..params…) LoRa::new(ExternalRadioKindImpl::new(BoardType::CustomSx1261_2, spi, iv), …other_params…)
- LoRa chips supported by this crate
- Valid coding rates for one or more LoRa chips supported by this crate
- Errors types reported during LoRa physical layer processing
- The state of the radio
- Valid spreading factors for one or more LoRa chips supported by this crate